searchNodes=[{"type":"module","title":"Prove","doc":"Prove provides the macros prove and batch to write simple tests in ExUnit shorter. A prove is just helpful for elementary tests. Prove generates one test with one assert for every prove . The disadvantage of these macros is that the tests are containing fewer descriptions. For this reason and also if a prove looks too complicated, a regular test is to prefer. Example defmodule NumTest do use ExUnit.Case import Prove defmodule Num do def check ( 0 ) , do : :zero def check ( x ) when is_integer ( x ) do case rem ( x , 2 ) do 0 -&gt; :even 1 -&gt; :odd end end def check ( _ ) , do : :error end describe &quot;check/1&quot; do prove Num . check ( 0 ) == :zero batch &quot;returns :odd or :even&quot; do prove Num . check ( 1 ) == :odd prove Num . check ( 2 ) == :even prove &quot;for big num&quot; , Num . check ( 2_000 ) == :even end batch &quot;returns :error&quot; do prove Num . check ( &quot;1&quot; ) == :error prove Num . check ( nil ) == :error end end end The example above generates the following tests: $&gt; mix test test/num_test.exs --trace --seed 0 NumTest [test/num_test.exs] * prove check/1 (1) (0.00ms) [L#20] * prove check/1 returns :odd or :even (1) (0.00ms) [L#23] * prove check/1 returns :odd or :even (2) (0.00ms) [L#24] * prove check/1 returns :odd or :even for big num (1) (0.00ms) [L#25] * prove check/1 returns :error (1) (0.00ms) [L#29] * prove check/1 returns :error (2) (0.00ms) [L#30] Finished in 0.08 seconds (0.00s async, 0.08s sync) 6 proves, 0 failures Randomized with seed 0 The benefit of prove is that tests with multiple asserts can be avoided. The example above with regular test s: ... describe &quot;check/1&quot; do test &quot;returns :zero&quot; do assert Num . check ( 0 ) == :zero end test &quot;returns :odd or :even&quot; do assert Num . check ( 1 ) == :odd assert Num . check ( 2 ) == :even assert Num . check ( 2_000 ) == :even end test &quot;returns :error&quot; do assert Num . check ( &quot;1&quot; ) == :error assert Num . check ( nil ) == :error end end ... $&gt; mix test test/num_test.exs --trace --seed 0 NumTest [test/num_test.exs] * test check/1 returns :zero (0.00ms) [L#36] * test check/1 returns :odd or :even (0.00ms) [L#40] * test check/1 returns :error (0.00ms) [L#46] Finished in 0.03 seconds (0.00s async, 0.03s sync) 3 tests, 0 failures Randomized with seed 0","ref":"Prove.html"},{"type":"macro","title":"Prove.batch/2","doc":"Creates a batch of proves. A batch adds the description to every prove . This can be used to group proves s with a context. Every prove is still an own test . Code like: batch &quot;valid&quot; do prove 1 == 1 prove &quot;really&quot; , 2 == 2 end is equivalent to: test &quot;valid (1)&quot; do assert 1 == 1 end test &quot;valid really (1)&quot; do assert 2 == 2 end","ref":"Prove.html#batch/2"},{"type":"macro","title":"Prove.prove/2","doc":"A macro to write simple a simple test shorter. Code like: prove identity(5) == 5 prove identity(6) &gt; 5 prove &quot;check:&quot;, identity(7) == 7 is equivalent to: test &quot;(1)&quot; do assert identity ( 5 ) == 5 end test &quot;(2)&quot; do assert identity ( 6 ) &gt; 5 end test &quot;check: (1)&quot; do assert identity ( 7 ) == 7 end prove supports the operators == , != , === , !== , &lt; , &lt;= , &gt; , &gt;= , and =~ .","ref":"Prove.html#prove/2"}]